@@ -12,13 +12,16 @@ class Conversations:
         return await self._driver._execute_api_get(endpoint)
 
     _CREATE = 'workspace/items/{}/conversation/items'
-    async def create(self, workspace_id, *, user_ids=[], conversation_type='direct', display_name=None):
+    async def create(self, workspace_id, *, user_ids=[], conversation_type='direct', display_name=None, icon_hash=None):
         body = {
             'user_ids': user_ids,
             'type': conversation_type,
         }
         if display_name:
             body["display_name"] = display_name
+        
+        if icon_hash:
+            body["icon_hash"] = icon_hash
         return await self._driver._execute_api_post(self._CREATE.format(workspace_id), body=body)
 
     _PUBLICS = 'workspace/items/{}/conversation/public'
@@ -61,5 +64,11 @@ class Conversations:
         endpoint = self._UNARCHIVE.format(workspace_id, conversation_id)
         return await self._driver._execute_api_post(endpoint, body=body)
 
+    _CHANGE_ROLES = "workspace/items/{}/conversation/items/{}/members/items/{}/roles"
+    async def change_member_roles(self, workspace_id, conversation_id, user_id, roles):
+        body = roles
+        endpoint = self._CHANGE_ROLES.format(workspace_id, conversation_id, user_id)
+        return await self._driver._execute_api_post(endpoint, body=body)
+
 
 
